ALTER TABLE PRIJAVE ADD ID_PRIJAVE INTEGER;

CREATE INDEX PRIJAVE_OD_IDX ON PRIJAVE (OD);

CREATE INDEX PRIJAVE_DATUM_KREIRANJA_IDX ON PRIJAVE (DATUM_KREIRANJA);

CREATE SEQUENCE PRIJAVE_SEQ START WITH 1;

UPDATE PRIJAVE SET ID_PRIJAVE = PRIJAVE_SEQ.NextVal WHERE ID_PRIJAVE IS NULL;

ALTER TABLE PRIJAVE MODIFY ID_PRIJAVE NOT NULL;

ALTER TABLE PRIJAVE ADD CONSTRAINT PRIJAVE_PK PRIMARY KEY (ID_PRIJAVE);

CREATE OR REPLACE TRIGGER PRIJAVE_TRG
    BEFORE INSERT
    ON PRIJAVE
    REFERENCING NEW AS NEW OLD AS OLD
    FOR EACH ROW
BEGIN
    IF (:NEW.ID IS NULL) THEN
        SELECT PRIJAVE_SEQ.NEXTVAL INTO :NEW.ID  FROM DUAL;;
    END IF;;
END;;
;

INSERT INTO MARINA_SEQUENCES (TABLENAME, FIELDNAME, SEQUENCE_NAME, COUNTER_TYPE)
VALUES ('OSEBE', 'ID', 'OSEBE_SEQ', 'S_KLJUCI');

CREATE TABLE PRIJAVE_LOG (
    ID INTEGER NOT NULL,
    DAT_PRIJAVE DATE NOT NULL,
    DAT_POSILJANJA DATE NOT NULL,
    REQUEST_XML CLOB,
    PACKAGE_GUID VARCHAR2(50),
    COUNT_OK INTEGER,
    COUNT_ERR INTEGER,
    RESPONSE_XML CLOB,
    STATUS VARCHAR2(1) NOT NULL,
    STATUS_MESSAGE VARCHAR2(250)
);

ALTER TABLE PRIJAVE_LOG ADD CONSTRAINT PRIJAVE_LOG_PK PRIMARY KEY (ID);

INSERT INTO MARINA_SEQUENCES (TABLENAME, FIELDNAME, SEQUENCE_NAME, COUNTER_TYPE)
VALUES ('PRIJAVE_LOG', 'ID', 'PRIJAVE_LOG_SEQ', 'S_KLJUCI');

CREATE OR REPLACE VIEW V_PRIJAVE AS SELECT 
    P.ID_PRIJAVE,
    P.ID,
    P.OD,
    P.DOO,
    P.DATUM_KREIRANJA,
    P.USER_SPREMEMBE,
    P.CAS_PRIJAVE,
    P.CAS_ODJAVE,
    P.DATUM_SPREMEMBE,
    P.LICENCA_SKIPER,
    P.LICENCA_VHS,
    P.VRSTA_GOSTA AS SIFRA_VRSTE_GOSTA,
    P.STATUS_GOSTA AS SIFRA_STATUSA_GOSTA,
    G.OPIS AS VRSTA_GOSTA,
    S.OPIS AS STATUS_GOSTA,
    P.ID_OSEBE,
    P.DATUM_VHODA_V_DRZAVO,
    P.KRAJ_VHODA_V_DRZAVO,
    P.TIP_OBJEKTA AS SIFRA_TIPA_OBJEKTA,
    T.OPIS AS TIP_OBJEKTA,
    O.IME,
    O.PRIIMEK,
    O.SPOL,
    O.DATUM_ROJSTVA,
    O.VRSTA_DOKUMENTA AS SIFRA_VRSTE_DOKUMENTA,
    D.OPIS AS VRSTA_DOKUMENTA,
    O.N_DOKUMENTA,
    O.MESTO_ROJSTVA,
    D1.OPIS DRZAVA,
    D1.OZNAKA AS OZNAKA_DRZAVE,
    D2.OPIS AS DRZAVA_ROJSTVA,
    D2.OZNAKA AS OZNAKA_DRZAVE_ROJSTVA,
    O.MUP,
    P.ID_PLOVILA,
    P.ID_REZERVACIJE
FROM 
    PRIJAVE P 
    LEFT OUTER JOIN OSEBE O ON O.ID = P.ID_OSEBE
    LEFT OUTER JOIN NNDRZAVE D1 ON D1.SIFRA = O.NDRZAVA
    LEFT OUTER JOIN NNDRZAVE D2 ON D2.SIFRA = O.DRZAVA_ROJSTVA
    LEFT OUTER JOIN NNDOKUME D ON D.SIFRA = O.VRSTA_DOKUMENTA
    LEFT OUTER JOIN NVRSGOS G ON G.SIFRA = P.VRSTA_GOSTA
    LEFT OUTER JOIN NSTAGOS S ON S.SIFRA = P.STATUS_GOSTA
    LEFT OUTER JOIN NNTIP T ON T.SIFRA = P.TIP_OBJEKTA
;

CREATE OR REPLACE VIEW V_OSEBE AS SELECT
  O.ID,
  O.NTitle,
  NT.Opis AS NTitleOpis,
  O.Ime,
  O.Priimek,
  O.Naslov,
  O.Mesto,
  O.Posta,
  O.NDrzava,
  D.Interni_Opis AS NDrzavaOpis,
  O.Datum_Rojstva,
  O.Vrsta_Dokumenta,
  DOK.Interni_Opis AS Vrsta_Dokumenta_Opis,
  O.N_Dokumenta,
  O.Knjiga_Gostov,
  O.Mesto_Rojstva,
  O.Drzava_Rojstva,
  DR.Interni_Opis AS DrzavaRojstvaOpis,
  O.Vrsta_Osebe,
  VO.Interni_Opis AS Vrsta_Osebe_Opis,
  O.Status_Osebe,
  SO.Interni_Opis AS Status_Osebe_Opis,
  O.Spol,
  SPOL.Interni_Opis AS Spol_Opis,
  O.MUP,
  O.Telefon,
  O.EMail,
  P.OD AS Prijava_Od,
  P.Id_Plovila,
  PL.Ime AS Plovilo_Ime
FROM
  (SELECT 
    O.*,
    (SELECT MAX(P.ID_PRIJAVE) FROM PRIJAVE P WHERE P.ID_OSEBE = O.ID AND P.OD = (SELECT MAX(P2.OD) FROM PRIJAVE P2 WHERE P2.ID_OSEBE = P.ID_OSEBE)) ID_PRIJAVE
    FROM OSEBE O
  ) O
  LEFT OUTER JOIN NNDRZAVE D ON D.Sifra = O.NDrzava
  LEFT OUTER JOIN NNDRZAVE DR ON DR.Sifra = O.Drzava_Rojstva
  LEFT OUTER JOIN NNTITLE NT ON NT.Sifra = O.NTitle
  LEFT OUTER JOIN NNDOKUME DOK ON DOK.Sifra = O.Vrsta_Dokumenta
  LEFT OUTER JOIN NVRSGOS VO ON VO.Sifra = O.Vrsta_Osebe
  LEFT OUTER JOIN NSTAGOS SO ON SO.Sifra = O.Status_Osebe
  LEFT OUTER JOIN NNSPOL SPOL ON SPOL.Sifra = O.Spol
  LEFT OUTER JOIN PRIJAVE P ON P.ID_PRIJAVE = O.ID_PRIJAVE
  LEFT OUTER JOIN PLOVILA PL ON PL.ID = P.ID_PLOVILA
;

CREATE OR REPLACE VIEW V_OSEBE_PL AS SELECT
  O.ID,
  O.NTitle,
  NT.Opis AS NTitleOpis,
  O.Ime,
  O.Priimek,
  O.Naslov,
  O.Mesto,
  O.Posta,
  O.NDrzava,
  D.Interni_Opis AS NDrzavaOpis,
  O.Datum_Rojstva,
  O.Vrsta_Dokumenta,
  DOK.Interni_Opis AS Vrsta_Dokumenta_Opis,
  O.N_Dokumenta,
  O.Knjiga_Gostov,
  O.Mesto_Rojstva,
  O.Drzava_Rojstva,
  DR.Interni_Opis AS DrzavaRojstvaOpis,
  O.Vrsta_Osebe,
  VO.Interni_Opis AS Vrsta_Osebe_Opis,
  O.Status_Osebe,
  SO.Interni_Opis AS Status_Osebe_Opis,
  O.Spol,
  SPOL.Interni_Opis AS Spol_Opis,
  O.MUP,
  O.Telefon,
  O.EMail,
  P.OD AS Prijava_Od,
  P.Id_Plovila,
  PL.Ime AS Plovilo_Ime
FROM
  OSEBE O
  LEFT OUTER JOIN NNDRZAVE D ON D.Sifra = O.NDrzava
  LEFT OUTER JOIN NNDRZAVE DR ON DR.Sifra = O.Drzava_Rojstva
  LEFT OUTER JOIN NNTITLE NT ON NT.Sifra = O.NTitle
  LEFT OUTER JOIN NNDOKUME DOK ON DOK.Sifra = O.Vrsta_Dokumenta
  LEFT OUTER JOIN NVRSGOS VO ON VO.Sifra = O.Vrsta_Osebe
  LEFT OUTER JOIN NSTAGOS SO ON SO.Sifra = O.Status_Osebe
  LEFT OUTER JOIN NNSPOL SPOL ON SPOL.Sifra = O.Spol
  LEFT OUTER JOIN (
    SELECT P.ID_PLOVILA, P.ID_OSEBE, MAX(P.OD) AS OD FROM PRIJAVE P GROUP BY P.ID_PLOVILA, P.ID_OSEBE
  ) P ON P.ID_OSEBE = O.ID
  LEFT OUTER JOIN PLOVILA PL ON PL.ID = P.ID_PLOVILA
;

insert into verzije_baza
(id, dt_vpis, verzija, ver_nr, opis) values (1818, SYSDATE, '5.5', 1738, 'Prijava gostov')
;
